"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostalCodeFind = void 0;
/* The line `import { postalCodes } from '../../constants/postalCode';` is importing the `postalCodes`
variable from the `postalCode` module in the `constants` directory. This variable likely contains an
array of postal code data, which is used in the `PostalCodeFind` function to search for a given
postal code and find its corresponding province and city. */
const postalCode_1 = require("../../constants/postalCode");
/* The line `import { Fa_To_En } from '../../parser/number/FaToEn';` is importing the `Fa_To_En`
function from the `FaToEn` module in the `parser/number` directory. This function is likely used to
convert Persian (Farsi) numbers to English numbers. */
const FaToEn_1 = require("../../parser/number/FaToEn");
/**
 * Finds the province and city of a given postal code.
 * @param {string} code - The postal code to search for.
 * @returns {PostalCodeFindType | undefined | boolean} - An object containing the province and city of the postal code, or undefined if the postal code is not found, or false if the input is invalid.
 */
const PostalCodeFind = (code) => {
    code = (0, FaToEn_1.Fa_To_En)(code.slice(0, 5));
    if (code) {
        const postFiltered = postalCode_1.postalCodes === null || postalCode_1.postalCodes === void 0 ? void 0 : postalCode_1.postalCodes.find((item) => (0, FaToEn_1.Fa_To_En)(item.from) <= code && code <= (0, FaToEn_1.Fa_To_En)(item.to));
        if (postFiltered) {
            return { province: postFiltered.province, city: postFiltered.city };
        }
    }
    return false;
};
exports.PostalCodeFind = PostalCodeFind;
